;;; DO NOT MODIFY THIS FILE
(if (featurep 'tooltalk-autoloads) (error "Already loaded"))

(provide 'tooltalk-autoloads)

;;;### (autoloads nil "_pkg" "tooltalk/_pkg.el")

(package-provide 'tooltalk :version 1.05 :type 'regular)

;;;***
